@@ -3,10 +3,11 @@ import ftplib
 import os
 import site
 import platform
+import pkg_resources
 from typing import Callable, Union
 from tqdm import tqdm
 
-file_name = 'libOneXAPI'
+file_name = 'libOneXAPI.' + pkg_resources.get_distribution('OneXAPI').version
 
 def file_write(file, data):
    file.write(data) 
@@ -23,40 +24,28 @@ def ftp_download(down_path, loc_file_name) :
         data = []
         ftp.dir(data.append)
         
-        fd = open(os.path.join(down_path, loc_file_name),'wb')
         size = ftp.size(loc_file_name)
         pbar=tqdm(total=size)
         
         bufsize=1024
-        def bar(data):
-            fd.write(data)
-            pbar.update(len(data))
+        with open(os.path.join(down_path, loc_file_name),'wb') as fd:
+            def bar(data):
+                fd.write(data)
+                pbar.update(len(data))
 
-        ftp.retrbinary("RETR " + loc_file_name, bar, bufsize)
+            ftp.retrbinary("RETR " + loc_file_name, bar, bufsize)
 
-        pbar.close()
-        fd.close()
+            pbar.close()
         
     except Exception as e:
-        os.remove(down_path + loc_file_name)
+        if os.path.exists(os.path.join(down_path, loc_file_name)):
+            os.remove(os.path.join(down_path, loc_file_name))
         print("Failed to download dynamic library from OneX FTP Server. Please contact OneX Team.")
         print("Error : " + str(e))
         exit()
 
-if platform.system() == 'Linux' :               # Linux
-    base_path = ""
-    for candidate in site.getsitepackages():
-        if 'site-packages' in candidate:
-            base_path = candidate
-            break
-        elif 'dist-packages' in candidate:
-            base_path = candidate
-            break
-    if base_path == "Can't find package folder. Please contact OneX team":
-        print("")
-        exit()
-        
-    base_path = os.path.join(base_path, 'OneXAPI_libs')
+if platform.system() == 'Linux' :               # Linux        
+    base_path = os.path.join(os.path.expanduser('~'), '.OneXAPI_libs')
     if not os.path.exists(base_path):
         os.mkdir(base_path)
     if not os.path.exists(os.path.join(base_path, file_name + '.so')):
